==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/ast.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Nun pudo unviase'l corréu a los usuarios siguientes: %s",
    "Turned on maintenance mode" : "Activáu'l mou de caltenimientu",
    "Turned off maintenance mode" : "Apagáu'l mou de caltenimientu",
    "Updated database" : "Base de datos anovada",
    "Checked database schema update" : "Anovamientu del esquema de base de datos revisáu",
    "Checked database schema update for apps" : "Anovamientu del esquema de base de datos p'aplicaciones revisáu",
    "Updated \"%s\" to %s" : "Anováu \"%s\" a %s",
    "No image or file provided" : "Nun s'especificó nenguna imaxe o ficheru",
    "Unknown filetype" : "Triba de ficheru desconocida",
    "Invalid image" : "Imaxe inválida",
    "No temporary profile picture available, try again" : "Nengún perfil d'imaxe temporal disponible, intentalo de nueves",
    "No crop data provided" : "Nun s'apurrió'l retayu de datos",
    "Sunday" : "Domingu",
    "Monday" : "Llunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Xueves",
    "Friday" : "Vienres",
    "Saturday" : "Sábadu",
    "Sun." : "Dom.",
    "Mon." : "Llu.",
    "Tue." : "Mar.",
    "Wed." : "Mié.",
    "Thu." : "Xue.",
    "Fri." : "Vie.",
    "Sat." : "Sáb.",
    "January" : "Xineru",
    "February" : "Febreru",
    "March" : "Marzu",
    "April" : "Abril",
    "May" : "Mayu",
    "June" : "Xunu",
    "July" : "Xunetu",
    "August" : "Agostu",
    "September" : "Setiembre",
    "October" : "Ochobre",
    "November" : "Payares",
    "December" : "Avientu",
    "Jan." : "Xin.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "May.",
    "Jun." : "Xun.",
    "Jul." : "Xnt.",
    "Aug." : "Ago.",
    "Sep." : "Set.",
    "Oct." : "Och.",
    "Nov." : "Pay.",
    "Dec." : "Avi.",
    "Settings" : "Axustes",
    "Saving..." : "Guardando...",
    "seconds ago" : "hai segundos",
    "Couldn't send reset email. Please contact your administrator." : "Nun pudo unviase'l corréu de reaniciu. Por favor, contauta col alministrador.",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Unviósete al corréu l'enllaz pa reaniciar la to contraseña. Si nun lu recibes nuna cantidá razonable de tiempu, comprueba les tos carpetes de corréu puxarra. <br>Si nun ta ehí, entruga al to alministrador llocal",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Los tos ficheros tán crifraos. Si nun habilitesti la clave de recuperación, nun habrá forma de recuperar los tos datos dempués de que se reanicie la to contraseña.<br />Si nun tas seguru de qué facer, por favor contauta col to alministrador enantes que sigas. <br />¿De xuru quies siguir?",
    "I know what I'm doing" : "Sé lo que toi faciendo",
    "Password can not be changed. Please contact your administrator." : "Nun pue camudase la contraseña. Por favor, contauta col alministrador.",
    "No" : "Non",
    "Yes" : "Sí",
    "Choose" : "Esbillar",
    "Error loading file picker template: {error}" : "Fallu cargando'l ficheru de plantía d'escoyeta: {error}",
    "Ok" : "Aceutar",
    "Error loading message template: {error}" : "Fallu cargando'l mensaxe de la plantía: {error}",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflictu de ficheru","{count} conflictos de ficheru "],
    "One file conflict" : "Conflictu nun ficheru",
    "New Files" : "Ficheros nuevos",
    "Already existing files" : "Ficheros qu'esisten yá",
    "Which files do you want to keep?" : "¿Qué ficheros quies caltener?",
    "If you select both versions, the copied file will have a number added to its name." : "Si seleiciones dambes versiones, el ficheru copiáu va tener un númberu amestáu al so nome",
    "Cancel" : "Encaboxar",
    "Continue" : "Continuar",
    "(all selected)" : "(esbillao too)",
    "({count} selected)" : "(esbillaos {count})",
    "Error loading file exists template" : "Falu cargando plantía de ficheru esistente",
    "Very weak password" : "Contraseña mui feble",
    "Weak password" : "Contraseña feble",
    "So-so password" : "Contraseña pasable",
    "Good password" : "Contraseña bona",
    "Strong password" : "Contraseña mui bona",
    "Shared" : "Compartíu",
    "Shared with {recipients}" : "Compartío con {recipients}",
    "Error" : "Fallu",
    "Error while sharing" : "Fallu mientres la compartición",
    "Error while unsharing" : "Fallu mientres se dexaba de compartir",
    "Error while changing permissions" : "Fallu mientres camudaben los permisos",
    "Error setting expiration date" : "Fallu afitando la fecha de caducidá",
    "The public link will expire no later than {days} days after it is created" : "L'enllaz públicu va caducar enantes de {days} díes dende la so creación",
    "Set expiration date" : "Afitar la data de caducidá",
    "Expiration" : "Caducidá",
    "Expiration date" : "Data de caducidá",
    "Sending ..." : "Unviando ...",
    "Email sent" : "Corréu unviáu",
    "Resharing is not allowed" : "Recompartir nun ta permitíu",
    "Share link" : "Compartir enllaz",
    "Password protect" : "Protexer con contraseña",
    "Password" : "Contraseña",
    "Choose a password for the public link" : "Escueyi una contraseña pal enllaz públicu",
    "Email link to person" : "Enllaz de corréu-e a la persona",
    "Send" : "Unviar",
    "Shared with you and the group {group} by {owner}" : "Compartíu contigo y col grupu {group} por {owner}",
    "Shared with you by {owner}" : "Compartíu contigo por {owner}",
    "Shared in {item} with {user}" : "Compartíu en {item} con {user}",
    "group" : "grupu",
    "notify by email" : "notificar per corréu",
    "Unshare" : "Dexar de compartir",
    "can share" : "pue compartir",
    "can edit" : "pue editar",
    "create" : "crear",
    "delete" : "desaniciar",
    "access control" : "control d'accesu",
    "Share" : "Compartir",
    "Warning" : "Avisu",
    "The object type is not specified." : "El tipu d'oxetu nun ta especificáu.",
    "Enter new" : "Introducir nueva",
    "Delete" : "Desaniciar",
    "Add" : "Amestar",
    "Edit tags" : "Editar etiquetes",
    "Error loading dialog template: {error}" : "Fallu cargando plantía de diálogu: {error}",
    "No tags selected for deletion." : "Nun s'esbillaron etiquetes pa desaniciar.",
    "Updating {productName} to version {version}, this may take a while." : "Anovando {productName} a la versión {version}, esto pue llevar un tiempu.",
    "Please reload the page." : "Por favor, recarga la páxina",
    "The update was successful. Redirecting you to ownCloud now." : "L'anovamientu fízose con ésitu. Redirixiendo agora al to ownCloud.",
    "Couldn't reset password because the token is invalid" : "Nun pudo reaniciase la contraseña porque'l token ye inválidu",
    "Couldn't send reset email. Please make sure your username is correct." : "Nun pudo unviase'l corréu. Por favor, asegurate que'l to nome d'usuariu seya correutu",
    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Nun pudo unviase'l corréu porque nun hai direición de corréu pa esti nome d'usuariu. Por favor, contauta col alministrador",
    "%s password reset" : "%s restablecer contraseña",
    "Use the following link to reset your password: {link}" : "Usa'l siguiente enllaz pa restablecer la to contraseña: {link}",
    "New password" : "Contraseña nueva",
    "New Password" : "Contraseña nueva",
    "Reset password" : "Restablecer contraseña",
    "Personal" : "Personal",
    "Users" : "Usuarios",
    "Apps" : "Aplicaciones",
    "Admin" : "Alministrador",
    "Help" : "Ayuda",
    "Error loading tags" : "Fallu cargando les etiquetes",
    "Tag already exists" : "Yá esiste la etiqueta",
    "Error deleting tag(s)" : "Fallu desaniciando etiqueta(es)",
    "Error tagging" : "Fallu etiquetando",
    "Error untagging" : "Fallu al quitar etiquetes",
    "Error favoriting" : "Fallu al marcar favoritos",
    "Error unfavoriting" : "Fallu al desmarcar favoritos",
    "Access forbidden" : "Accesu denegáu",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hola, ¿qué hai?\n\nnamái déxanos dicite que %s compartió %s contigo.\nVelu: %s\n\n",
    "The share will expire on %s." : "La compartición va caducar el %s.",
    "Cheers!" : "¡Salú!",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "El to direutoriu de datos y ficheros seique ye accesible dende internet por mor qu'el ficheru .htaccess nun furrula.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Pa informase de cómo configurar el so sirvidor, por favor güeya la  <a href=\"%s\" target=\"_blank\">documentación</a>.",
    "Create an <strong>admin account</strong>" : "Crea una <strong>cuenta d'alministrador</strong>",
    "Username" : "Nome d'usuariu",
    "Storage & database" : "Almacenamientu y Base de datos",
    "Data folder" : "Carpeta de datos",
    "Configure the database" : "Configura la base de datos",
    "Only %s is available." : "Namái ta disponible %s",
    "Database user" : "Usuariu de la base de datos",
    "Database password" : "Contraseña de la base de datos",
    "Database name" : "Nome de la base de datos",
    "Database tablespace" : "Espaciu de tables de la base de datos",
    "Database host" : "Agospiador de la base de datos",
    "Finish setup" : "Finar la configuración ",
    "Finishing …" : "Finando ...",
    "Log out" : "Zarrar sesión",
    "Search" : "Guetar",
    "Server side authentication failed!" : "Falló l'autenticación nel sirvidor!",
    "Please contact your administrator." : "Por favor, contauta col to alministrador",
    "Log in" : "Aniciar sesión",
    "remember" : "recordar",
    "Alternative Logins" : "Anicios de sesión alternativos",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hola, ¿qué hai?,<br><br>namái déxamos dicite que %s compartió <strong>%s</strong> contigo.\n<br><a href=\"%s\">¡Velu!</a><br><br>",
    "This ownCloud instance is currently in single user mode." : "Esta instalación d'ownCloud ta en mou d'usuariu únicu.",
    "This means only administrators can use the instance." : "Esto quier dicir que namái pue usala un alministrador.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contauta col alministrador si esti problema sigui apaeciendo.",
    "Thank you for your patience." : "Gracies pola to paciencia.",
    "You are accessing the server from an untrusted domain." : "Tas accediendo al sirvidor dende un dominiu non confiáu.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Por favor, contauta col alministrador. Si yes l'alministrador, configura l'axuste \"trusted_domain\" en config/config.php. Hai un exemplu en config/config.sample.php.",
    "Add \"%s\" as trusted domain" : "Amestáu \"%s\" como dominiu de confianza",
    "The theme %s has been disabled." : "Deshabilitóse'l tema %s.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Enantes de siguir, asegúrate de que se fizo una copia de seguridá de la base de datos, la carpeta de configuración y la carpeta de datos.",
    "Start update" : "Aniciar anovamientu"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/ast.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Nun pudo unviase'l corréu a los usuarios siguientes: %s",
    "Turned on maintenance mode" : "Activáu'l mou de caltenimientu",
    "Turned off maintenance mode" : "Apagáu'l mou de caltenimientu",
    "Updated database" : "Base de datos anovada",
    "Checked database schema update" : "Anovamientu del esquema de base de datos revisáu",
    "Checked database schema update for apps" : "Anovamientu del esquema de base de datos p'aplicaciones revisáu",
    "Updated \"%s\" to %s" : "Anováu \"%s\" a %s",
    "No image or file provided" : "Nun s'especificó nenguna imaxe o ficheru",
    "Unknown filetype" : "Triba de ficheru desconocida",
    "Invalid image" : "Imaxe inválida",
    "No temporary profile picture available, try again" : "Nengún perfil d'imaxe temporal disponible, intentalo de nueves",
    "No crop data provided" : "Nun s'apurrió'l retayu de datos",
    "Couldn't reset password because the token is invalid" : "Nun pudo reaniciase la contraseña porque'l token ye inválidu",
    "Couldn't send reset email. Please make sure your username is correct." : "Nun pudo unviase'l corréu. Por favor, asegurate que'l to nome d'usuariu seya correutu",
    "%s password reset" : "%s restablecer contraseña",
    "Couldn't send reset email. Please contact your administrator." : "Nun pudo unviase'l corréu de reaniciu. Por favor, contauta col alministrador.",
    "Sunday" : "Domingu",
    "Monday" : "Llunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Xueves",
    "Friday" : "Vienres",
    "Saturday" : "Sábadu",
    "Sun." : "Dom.",
    "Mon." : "Llu.",
    "Tue." : "Mar.",
    "Wed." : "Mié.",
    "Thu." : "Xue.",
    "Fri." : "Vie.",
    "Sat." : "Sáb.",
    "January" : "Xineru",
    "February" : "Febreru",
    "March" : "Marzu",
    "April" : "Abril",
    "May" : "Mayu",
    "June" : "Xunu",
    "July" : "Xunetu",
    "August" : "Agostu",
    "September" : "Setiembre",
    "October" : "Ochobre",
    "November" : "Payares",
    "December" : "Avientu",
    "Jan." : "Xin.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "May.",
    "Jun." : "Xun.",
    "Jul." : "Xnt.",
    "Aug." : "Ago.",
    "Sep." : "Set.",
    "Oct." : "Och.",
    "Nov." : "Pay.",
    "Dec." : "Avi.",
    "Settings" : "Axustes",
    "Saving..." : "Guardando...",
    "Dismiss" : "Encaboxar",
    "seconds ago" : "hai segundos",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Unviósete al corréu l'enllaz pa reaniciar la to contraseña. Si nun lu recibes nuna cantidá razonable de tiempu, comprueba les tos carpetes de corréu puxarra. <br>Si nun ta ehí, entruga al to alministrador llocal",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Los tos ficheros tán crifraos. Si nun habilitesti la clave de recuperación, nun habrá forma de recuperar los tos datos dempués de que se reanicie la to contraseña.<br />Si nun tas seguru de qué facer, por favor contauta col to alministrador enantes que sigas. <br />¿De xuru quies siguir?",
    "I know what I'm doing" : "Sé lo que toi faciendo",
    "Password can not be changed. Please contact your administrator." : "Nun pue camudase la contraseña. Por favor, contauta col alministrador.",
    "No" : "Non",
    "Yes" : "Sí",
    "Choose" : "Esbillar",
    "Error loading file picker template: {error}" : "Fallu cargando'l ficheru de plantía d'escoyeta: {error}",
    "Ok" : "Aceutar",
    "Error loading message template: {error}" : "Fallu cargando'l mensaxe de la plantía: {error}",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflictu de ficheru","{count} conflictos de ficheru "],
    "One file conflict" : "Conflictu nun ficheru",
    "New Files" : "Ficheros nuevos",
    "Already existing files" : "Ficheros qu'esisten yá",
    "Which files do you want to keep?" : "¿Qué ficheros quies caltener?",
    "If you select both versions, the copied file will have a number added to its name." : "Si seleiciones dambes versiones, el ficheru copiáu va tener un númberu amestáu al so nome",
    "Cancel" : "Encaboxar",
    "Continue" : "Continuar",
    "(all selected)" : "(esbillao too)",
    "({count} selected)" : "(esbillaos {count})",
    "Error loading file exists template" : "Falu cargando plantía de ficheru esistente",
    "Very weak password" : "Contraseña mui feble",
    "Weak password" : "Contraseña feble",
    "So-so password" : "Contraseña pasable",
    "Good password" : "Contraseña bona",
    "Strong password" : "Contraseña mui bona",
    "Shared" : "Compartíu",
    "Shared with {recipients}" : "Compartío con {recipients}",
    "Error" : "Fallu",
    "Error while sharing" : "Fallu mientres la compartición",
    "Error while unsharing" : "Fallu mientres se dexaba de compartir",
    "Error setting expiration date" : "Fallu afitando la fecha de caducidá",
    "The public link will expire no later than {days} days after it is created" : "L'enllaz públicu va caducar enantes de {days} díes dende la so creación",
    "Set expiration date" : "Afitar la data de caducidá",
    "Expiration" : "Caducidá",
    "Expiration date" : "Data de caducidá",
    "Choose a password for the public link" : "Escueyi una contraseña pal enllaz públicu",
    "Sending ..." : "Unviando ...",
    "Email sent" : "Corréu unviáu",
    "Resharing is not allowed" : "Recompartir nun ta permitíu",
    "Share link" : "Compartir enllaz",
    "Link" : "Enllaz",
    "Password protect" : "Protexer con contraseña",
    "Password" : "Contraseña",
    "Allow editing" : "Permitir edición",
    "Email link to person" : "Enllaz de corréu-e a la persona",
    "Send" : "Unviar",
    "Shared with you and the group {group} by {owner}" : "Compartíu contigo y col grupu {group} por {owner}",
    "Shared with you by {owner}" : "Compartíu contigo por {owner}",
    "group" : "grupu",
    "remote" : "remotu",
    "notify by email" : "notificar per corréu",
    "Unshare" : "Dexar de compartir",
    "can share" : "pue compartir",
    "can edit" : "pue editar",
    "create" : "crear",
    "change" : "camudar",
    "delete" : "desaniciar",
    "access control" : "control d'accesu",
    "An error occured. Please try again" : "Hebo un fallu. Por favor, inténtalo dempués. ",
    "Share" : "Compartir",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Compartir con xente d'otros ownClouds usando la sintaxis usuariu@exemplu.com/owncloud",
    "Share with users or groups …" : "Compartir con usuarios o grupos",
    "Share with users, groups or remote users …" : "Compartir con usuarios, grupos o usuarios remotos",
    "Warning" : "Avisu",
    "Delete" : "Desaniciar",
    "Rename" : "Renomar",
    "The object type is not specified." : "El tipu d'oxetu nun ta especificáu.",
    "Enter new" : "Introducir nueva",
    "Add" : "Amestar",
    "Edit tags" : "Editar etiquetes",
    "Error loading dialog template: {error}" : "Fallu cargando plantía de diálogu: {error}",
    "No tags selected for deletion." : "Nun s'esbillaron etiquetes pa desaniciar.",
    "Updating {productName} to version {version}, this may take a while." : "Anovando {productName} a la versión {version}, esto pue llevar un tiempu.",
    "Please reload the page." : "Por favor, recarga la páxina",
    "The update was successful. Redirecting you to ownCloud now." : "L'anovamientu fízose con ésitu. Redirixiendo agora al to ownCloud.",
    "Personal" : "Personal",
    "Users" : "Usuarios",
    "Apps" : "Aplicaciones",
    "Admin" : "Alministrador",
    "Help" : "Ayuda",
    "Error loading tags" : "Fallu cargando les etiquetes",
    "Tag already exists" : "Yá esiste la etiqueta",
    "Error deleting tag(s)" : "Fallu desaniciando etiqueta(es)",
    "Error tagging" : "Fallu etiquetando",
    "Error untagging" : "Fallu al quitar etiquetes",
    "Error favoriting" : "Fallu al marcar favoritos",
    "Error unfavoriting" : "Fallu al desmarcar favoritos",
    "Access forbidden" : "Accesu denegáu",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hola, ¿qué hai?\n\nnamái déxanos dicite que %s compartió %s contigo.\nVelu: %s\n\n",
    "The share will expire on %s." : "La compartición va caducar el %s.",
    "Cheers!" : "¡Salú!",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "El to direutoriu de datos y ficheros seique ye accesible dende internet por mor qu'el ficheru .htaccess nun furrula.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Pa informase de cómo configurar el so sirvidor, por favor güeya la  <a href=\"%s\" target=\"_blank\">documentación</a>.",
    "Create an <strong>admin account</strong>" : "Crea una <strong>cuenta d'alministrador</strong>",
    "Username" : "Nome d'usuariu",
    "Storage & database" : "Almacenamientu y Base de datos",
    "Data folder" : "Carpeta de datos",
    "Configure the database" : "Configura la base de datos",
    "Only %s is available." : "Namái ta disponible %s",
    "Database user" : "Usuariu de la base de datos",
    "Database password" : "Contraseña de la base de datos",
    "Database name" : "Nome de la base de datos",
    "Database tablespace" : "Espaciu de tables de la base de datos",
    "Database host" : "Agospiador de la base de datos",
    "Finish setup" : "Finar la configuración ",
    "Finishing …" : "Finando ...",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hola, ¿qué hai?,<br><br>namái déxamos dicite que %s compartió <strong>%s</strong> contigo.\n<br><a href=\"%s\">¡Velu!</a><br><br>",
    "Log out" : "Zarrar sesión",
    "Search" : "Guetar",
    "Server side authentication failed!" : "Falló l'autenticación nel sirvidor!",
    "Please contact your administrator." : "Por favor, contauta col to alministrador",
    "Log in" : "Aniciar sesión",
    "Alternative Logins" : "Anicios de sesión alternativos",
    "Use the following link to reset your password: {link}" : "Usa'l siguiente enllaz pa restablecer la to contraseña: {link}",
    "New password" : "Contraseña nueva",
    "New Password" : "Contraseña nueva",
    "Reset password" : "Restablecer contraseña",
    "This ownCloud instance is currently in single user mode." : "Esta instalación d'ownCloud ta en mou d'usuariu únicu.",
    "This means only administrators can use the instance." : "Esto quier dicir que namái pue usala un alministrador.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contauta col alministrador si esti problema sigui apaeciendo.",
    "Thank you for your patience." : "Gracies pola to paciencia.",
    "You are accessing the server from an untrusted domain." : "Tas accediendo al sirvidor dende un dominiu non confiáu.",
    "Add \"%s\" as trusted domain" : "Amestáu \"%s\" como dominiu de confianza",
    "The theme %s has been disabled." : "Deshabilitóse'l tema %s.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Enantes de siguir, asegúrate de que se fizo una copia de seguridá de la base de datos, la carpeta de configuración y la carpeta de datos.",
    "Start update" : "Aniciar anovamientu"
},
"nplurals=2; plural=(n != 1);");
